searchData={"items":[{"type":"module","title":"AbsintheConstraints.Directive","doc":"Defines a GraphQL directive to add constraints to field definitions and argument definitions.\n\nExample\n\n```elixir\ninput_object :my_input do\n  field(:my_field, :integer, directives: [constraints: [min: 1]])\nend\n\n#...\nobject :my_query do\n  field :my_field, non_null(:string) do\n    arg(:my_arg, non_null(:string), directives: [constraints: [format: \"uuid\"]])\n    resolve(&MyResolver.resolve/2)\n  end\nend\n```","ref":"AbsintheConstraints.Directive.html"},{"type":"function","title":"AbsintheConstraints.Directive.expand_constraints/2","doc":"","ref":"AbsintheConstraints.Directive.html#expand_constraints/2"},{"type":"function","title":"AbsintheConstraints.Directive.expand_deprecate/2","doc":"Add a deprecation (with an optional reason) to a node.","ref":"AbsintheConstraints.Directive.html#expand_deprecate/2"},{"type":"function","title":"AbsintheConstraints.Directive.pipeline/1","doc":"","ref":"AbsintheConstraints.Directive.html#pipeline/1"},{"type":"module","title":"AbsintheConstraints.Phase","doc":"Defines an Absinthe Document Phase that validates inputs against constraints defined by the `constraints` directive.\n\nUse add_to_pipeline/2 to add this phase to your Absinthe pipeline.","ref":"AbsintheConstraints.Phase.html"},{"type":"function","title":"AbsintheConstraints.Phase.add_to_pipeline/2","doc":"","ref":"AbsintheConstraints.Phase.html#add_to_pipeline/2"},{"type":"function","title":"AbsintheConstraints.Phase.flag_invalid/1","doc":"","ref":"AbsintheConstraints.Phase.html#flag_invalid/1"},{"type":"function","title":"AbsintheConstraints.Phase.flag_invalid/2","doc":"","ref":"AbsintheConstraints.Phase.html#flag_invalid/2"},{"type":"function","title":"AbsintheConstraints.Phase.flag_invalid/3","doc":"","ref":"AbsintheConstraints.Phase.html#flag_invalid/3"},{"type":"function","title":"AbsintheConstraints.Phase.inherit_invalid/3","doc":"","ref":"AbsintheConstraints.Phase.html#inherit_invalid/3"},{"type":"function","title":"AbsintheConstraints.Phase.put_flag/2","doc":"","ref":"AbsintheConstraints.Phase.html#put_flag/2"},{"type":"module","title":"AbsintheConstraints.Validator","doc":"Defines all the constraint handlers for the `constraints` directive.","ref":"AbsintheConstraints.Validator.html"},{"type":"function","title":"AbsintheConstraints.Validator.handle_constraint/2","doc":"","ref":"AbsintheConstraints.Validator.html#handle_constraint/2"},{"type":"extras","title":"Absinthe Constraints","doc":"# Absinthe Constraints\n\nAn absinthe library to add type constraints to your GraphQL schema using directives.","ref":"readme.html"},{"type":"extras","title":"Installation - Absinthe Constraints","doc":"Install from [Hex.pm](https://hex.pm/packages/absinthe_constraints)\n\n```elixir\ndef deps do\n  [\n    {:absinthe_constraints, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Absinthe Constraints","doc":"##","ref":"readme.html#usage"},{"type":"extras","title":"1. Add the `constraints` directive's prototype schema to your schema - Absinthe Constraints","doc":"```elixir\ndefmodule MyAppWeb.Schema do\n  use Absinthe.Schema\n\n  @prototype_schema AbsintheConstraints.Directive\n\n  # Use `import_sdl`, etc...\nend\n```\n\n##","ref":"readme.html#1-add-the-constraints-directive-s-prototype-schema-to-your-schema"},{"type":"extras","title":"2. Add the document phase to your absinthe Pipeline - Absinthe Constraints","doc":"Example using `Absinthe.Plug`:\n\n```elixir\n# Somewhere in your router\n\ndef my_pipeline(config, opts) do\n  config\n  |> Absinthe.Plug.default_pipeline(opts)\n  |> AbsintheConstraints.Phase.add_to_pipeline(opts)\nend\n\nforward(\"/\", Absinthe.Plug, schema: MyAppWeb.Schema, pipeline: {__MODULE__, :my_pipeline})\n```\n\n##","ref":"readme.html#2-add-the-document-phase-to-your-absinthe-pipeline"},{"type":"extras","title":"3. Add constraints to your schema - Absinthe Constraints","doc":"```elixir\n# Somewhere in your schema\n\n# Adding constraints to input object's fields\ninput_object :coordinates do\n  field(:latitude, non_null(:float), directives: [constraints: [min: -90, max: 90]])\n  field(:longitude, non_null(:float), directives: [constraints: [min: -180, max: 180]])\nend\n\n# Adding constraints to query field's arguments\nobject :my_queries do\n  field :my_field, non_null(:string) do\n    arg(:id, non_null(:string), directives: [constraints: [format: \"uuid\"]])\n    resolve(&my_resolver/2)\n  end\nend\n```","ref":"readme.html#3-add-constraints-to-your-schema"},{"type":"extras","title":"Supported constraints - Absinthe Constraints","doc":"#","ref":"readme.html#supported-constraints"},{"type":"extras","title":"String - Absinthe Constraints","doc":"##","ref":"readme.html#string"},{"type":"extras","title":"min_length - Absinthe Constraints","doc":"```directives: [constraints: [min_length: 5]]```\nRestrict to a minimum length\n\n##","ref":"readme.html#min_length"},{"type":"extras","title":"max_length - Absinthe Constraints","doc":"```directives: [constraints: [max_length: 5]]```\nRestrict to a maximum length\n\n##","ref":"readme.html#max_length"},{"type":"extras","title":"format - Absinthe Constraints","doc":"```directives: [constraints: [format: \"uuid\"]]```\nEnsure value is in a particular format\n\nSupported formats:\n- `\"uuid\"` - uses :elixir_uuid to validate the value\n- `\"email\"` - uses a regex to validate the value\n\n##","ref":"readme.html#format"},{"type":"extras","title":"pattern - Absinthe Constraints","doc":"```directives: [constraints: [pattern: \"^[A-Z][0-9a-z]*$\"]]```\nEnsure value follows a specific Regex pattern\n\n#","ref":"readme.html#pattern"},{"type":"extras","title":"Number (integer/float) - Absinthe Constraints","doc":"##","ref":"readme.html#number-integer-float"},{"type":"extras","title":"min - Absinthe Constraints","doc":"```directives: [constraints: [min: 5]]```\nEnsure value is greater than or equal to\n\n##","ref":"readme.html#min"},{"type":"extras","title":"max - Absinthe Constraints","doc":"```directives: [constraints: [max: 5]]```\nEnsure value is less than or equal to\n\n#","ref":"readme.html#max"},{"type":"extras","title":"List - Absinthe Constraints","doc":"##","ref":"readme.html#list"},{"type":"extras","title":"min_items - Absinthe Constraints","doc":"```directives: [constraints: [min_items: 5]]```\nRestrict to a minimum number of items\n\n##","ref":"readme.html#min_items"},{"type":"extras","title":"max - Absinthe Constraints","doc":"```directives: [constraints: [max_items: 5]]```\nRestrict to a maximum number of items","ref":"readme.html#max"}],"content_type":"text/markdown"}